public class Competitor {
    // Flags for the competitor
    public static final int FLAG_INJURED        = (1<<0);
    public static final int FLAG_DISQUALIFIED   = (1<<1);

    // Database ID
    private int fCompetitorId;

    // Details about the competitor
    private String fFirstName, fLastName;
    private String fBeltRank;
    private String fAgeRange;
    private int fMatches = 0, fLosses = 0, fPasses = 0;
    private int fFlags = 0;

    // Default Constructor
    public Competitor() {
        fCompetitorId = -1; // Invalid entry
    }

    // Database Constructor
    public Competitor(int dataId) {
        fCompetitorId = dataId;
    }

    // Competitor Detail accessors and mutators
    public String getFirstName() {
        return fFirstName;
    }

    public String getLastName() {
        return fLastName;
    }

    public String getFullName() {
        return fFirstName + " " + fLastName;
    }

    public String getBeltRank() {
        return fBeltRank;
    }

    public String getAge() {
        return fAgeRange;
    }

    public int getMatches() {
        return fMatches;
    }
    
    public int getLosses() {
        return fLosses;
    }
    
    public int getPasses() {
        return fPasses;
    }

    public int getFlags() {
        return fFlags;
    }

    public void setName(String first, String last) {
        fFirstName = first;
        fLastName = last;
    }

    public void setBeltRank(String rank) {
        fBeltRank = rank;
    }

    public void setAge(String age) {
        fAgeRange = age;
    }

    public void setMatches(int matches) {
        fMatches = matches;
    }
    
    public void doMatch() {
        fMatches++;
    }
    
    public void setLosses(int losses) {
        fLosses = losses;
    }

    public void youLose() {
        // The competitor has lost a competition, so increment his or her losses
        fLosses++;
    }

    public void setPasses(int passes) {
        fPasses = passes;
    }

    public void pass() {
        // The competitor gets a pass for being the odd competitor in a match set
        fPasses++;
    }

    public void setFlags(int flags) {
        fFlags = flags;
    }

    // Info for the database -- package access only!
    int getId() {
        return fCompetitorId;
    }

    void setId(int id) {
        fCompetitorId = id;
    }
}
