import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.Font;
import javax.swing.*;

public class Bracket extends JFrame {
    private JPanel fPanel;
    private JButton fAddBtn, fSearchBtn, fUpdateBtn, fClearBtn;
    private JScrollPane fScrollPane;
    private JTextField fLastNameJTF;
    private JTextField fFirstNameJTF;
    private JComboBox fRankCombo;
    private JComboBox fAgeCombo;
    private JTextArea fOutputLog;
    private JButton fGenerateBtn;
    
    private Database fDbConnection;
    private int fFoundId = -1;

    private static String[] kRankOptions = { "White", "Yellow", "Green", "Blue", "Red", "Black" };
    private static String[] kAgeOptions = { "5-7", "8-10", "11-14", "15-17", "18+", "40+" };

    public Bracket() {
        super("Bracket");
        
        fPanel = new JPanel();
        
        fAddBtn = new JButton("Add");
        fAddBtn.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                Competitor comp = new Competitor();
                comp.setName(fFirstNameJTF.getText(), fLastNameJTF.getText());
                comp.setAge((String)fAgeCombo.getSelectedItem());
                comp.setBeltRank((String)fRankCombo.getSelectedItem());

                try {
                    fDbConnection.addCompetitor(comp);
                    fOutputLog.append(comp.getFullName() + " added\n");

                    // Reset values
                    fRankCombo.setSelectedIndex(0);
                    fAgeCombo.setSelectedIndex(0);
                    fFirstNameJTF.setText("");
                    fLastNameJTF.setText("");
                    fFoundId = -1;
                }
                catch (Exception ex) {
                    fOutputLog.append("Error adding " + comp.getFullName() +
                                      ": " + ex + "\n");
                    ex.printStackTrace();
                }
            }
        });


        fSearchBtn = new JButton("Search");
        fSearchBtn.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                Competitor found = null;
                try {
                    found = fDbConnection.findCompetitor(fFirstNameJTF.getText(), fLastNameJTF.getText());
                }
                catch (Exception ex) {
                    fOutputLog.append("Error searching the database: " + ex + "\n");
                    ex.printStackTrace();
                }

                if (found != null) {
                    fFoundId = found.getId();
                    fFirstNameJTF.setText(found.getFirstName());
                    fLastNameJTF.setText(found.getLastName());
                    fRankCombo.setSelectedIndex(-1);
                    fAgeCombo.setSelectedIndex(-1);
                    
                    for (int i=0; i<kRankOptions.length; i++) {
                        if (kRankOptions[i].equals(found.getBeltRank()))
                            fRankCombo.setSelectedIndex(i);
                    }
                    for (int i=0; i<kAgeOptions.length; i++) {
                        if (kAgeOptions[i].equals(found.getAge()))
                            fAgeCombo.setSelectedIndex(i);
                    }
                } else {
                    fFoundId = -1;
                    JOptionPane.showMessageDialog(null, "No competitor found", "Error", JOptionPane.ERROR_MESSAGE);
                }
            }
        });


        fClearBtn = new JButton("Clear");
        fClearBtn.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                // Reset values
                fRankCombo.setSelectedIndex(0);
                fAgeCombo.setSelectedIndex(0);
                fFirstNameJTF.setText("");
                fLastNameJTF.setText("");
                fFoundId = -1;
            }
        });

        
        fUpdateBtn = new JButton("Update");
        fUpdateBtn.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                if (fFoundId < 0) {
                    JOptionPane.showMessageDialog(null, "No competitor active (use search)", "Error", JOptionPane.ERROR_MESSAGE);
                    return;
                }

                Competitor comp = new Competitor(fFoundId);
                comp.setName(fFirstNameJTF.getText(), fLastNameJTF.getText());
                comp.setAge((String)fAgeCombo.getSelectedItem());
                comp.setBeltRank((String)fRankCombo.getSelectedItem());
                
                try {
                    fDbConnection.updateCompetitor(comp);
                    fOutputLog.append(comp.getFullName() + " updated\n");

                    // Reset values
                    fRankCombo.setSelectedIndex(0);
                    fAgeCombo.setSelectedIndex(0);
                    fFirstNameJTF.setText("");
                    fLastNameJTF.setText("");
                    fFoundId = -1;
                }
                catch (Exception ex) {
                    fOutputLog.append("Error updating " + comp.getFullName() +
                                      ": " + ex + "\n");
                    ex.printStackTrace();
                }
            }
        });
        
        fFirstNameJTF = new JTextField();
        fLastNameJTF = new JTextField();
        fRankCombo = new JComboBox(kRankOptions);
        fAgeCombo = new JComboBox(kAgeOptions);

        fPanel.setLayout(new GridLayout(3, 4));

        fPanel.add(fFirstNameJTF);
        fPanel.add(fLastNameJTF);
        fPanel.add(fAgeCombo);
        fPanel.add(fRankCombo);

        fPanel.add(new JLabel("First"));
        fPanel.add(new JLabel("Last"));
        fPanel.add(new JLabel("Age"));
        fPanel.add(new JLabel("Rank"));

        fPanel.add(fAddBtn);
        fPanel.add(fSearchBtn);
        fPanel.add(fClearBtn);
        fPanel.add(fUpdateBtn);
        
        /*
        fPanel.add(new JPanel());
        fPanel.add(new JPanel());
        fPanel.add(new JPanel());
        fPanel.add(new JPanel());
        */

        fGenerateBtn=new JButton("Generate Bracket");
        fGenerateBtn.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                try {
                    String[][] bracketData = fDbConnection.getBracket();
                    if (bracketData == null) {
                        fOutputLog.append("No competition data!\n");
                        return;
                    }
                    
                    JFrame bracket = new JFrame("Bracket");
                    bracket.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
                    bracket.getContentPane().add(new Window(bracketData));
                    bracket.pack();
                    bracket.setVisible(true);
                }
                catch (Exception ex) {
                    fOutputLog.append("Error generating a bracket: " + ex + "\n");
                    ex.printStackTrace();
                }
            }
        });
      
        add(fGenerateBtn, BorderLayout.SOUTH);
        add(fPanel, BorderLayout.NORTH);


        fOutputLog = new JTextArea(5, 10);
        fOutputLog.setEditable(false);
        fOutputLog.setBackground(Color.lightGray);
        Font fnt = new Font(Font.MONOSPACED, 0, 10);
        fOutputLog.setFont(fnt);

        fScrollPane = new JScrollPane(fOutputLog);

        add(fScrollPane, BorderLayout.CENTER);
        
        pack();
        setSize(640,480);
        setLocation(240, 150);

        setVisible(true);
        setDefaultCloseOperation(EXIT_ON_CLOSE);
        
        // Now we acquire the database connection to be used throughout the program
        try {
            fDbConnection = new Database("zrax.net", (short)3306, "bracket",
                                         "cs371", "bracket_db");
            fDbConnection.joinEvent("Test Event");
        }
        catch (Exception ex) {
            fOutputLog.append("Error connecting to the database: " + ex + "\n");
            ex.printStackTrace();
        }
    }

    public static void main(String args[]) {
        Bracket bracket = new Bracket();
    }
}
