/*
 * RefereeViewView.java
 */

package refereeview;

import org.jdesktop.application.SingleFrameApplication;
import org.jdesktop.application.FrameView;
import javax.swing.JOptionPane;

/**
 * The application's main frame.
 */
public class RefereeViewView extends FrameView {
    private Database fDbConnection;
    private Match fMatch;

    public RefereeViewView(SingleFrameApplication app) {
        super(app);

        initComponents();

        // Acquire the database connection
        try {
            fDbConnection = new Database("zrax.net", (short)3306, "bracket",
                                         "cs371", "bracket_db");
            fDbConnection.joinEvent("Test Event");
        }
        catch (Exception ex) {
            JOptionPane.showMessageDialog(null, "Error connecting to the database: " + ex, "Error", JOptionPane.ERROR_MESSAGE);
            ex.printStackTrace();
        }
        
        // Jump straight into the first match
        getNextMatch();
    }

    private void getNextMatch() {
        try {
            fMatch = fDbConnection.createMatch();
        }
        catch (Exception ex) {
            JOptionPane.showMessageDialog(null, "Error getting next match: " + ex, "Error", JOptionPane.ERROR_MESSAGE);
            ex.printStackTrace();
        }
        
        if (fMatch == null || fMatch.getMatchId() == -1) {
            JOptionPane.showMessageDialog(null, "No more matches!", "Done", JOptionPane.INFORMATION_MESSAGE);
            return;
        }
        fC1Injured.setSelected(false);
        fC2Injured.setSelected(false);
        fC1Disqualified.setSelected(false);
        fC2Disqualified.setSelected(false);
        fC1Name.setText(fMatch.getCompetitor1().getFullName());
        fC2Name.setText(fMatch.getCompetitor2().getFullName());
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        mainPanel = new javax.swing.JPanel();
        fC1Name = new javax.swing.JLabel();
        fC2Name = new javax.swing.JLabel();
        fC1Injured = new javax.swing.JCheckBox();
        fC1Disqualified = new javax.swing.JCheckBox();
        fC2Injured = new javax.swing.JCheckBox();
        fC2Disqualified = new javax.swing.JCheckBox();
        fC1Won = new javax.swing.JButton();
        fC2Won = new javax.swing.JButton();

        mainPanel.setName("mainPanel"); // NOI18N

        org.jdesktop.application.ResourceMap resourceMap = org.jdesktop.application.Application.getInstance(refereeview.RefereeViewApp.class).getContext().getResourceMap(RefereeViewView.class);
        fC1Name.setText(resourceMap.getString("fC1Name.text")); // NOI18N
        fC1Name.setName("fC1Name"); // NOI18N

        fC2Name.setText(resourceMap.getString("fC2Name.text")); // NOI18N
        fC2Name.setName("fC2Name"); // NOI18N

        fC1Injured.setText(resourceMap.getString("fC1Injured.text")); // NOI18N
        fC1Injured.setName("fC1Injured"); // NOI18N

        fC1Disqualified.setText(resourceMap.getString("fC1Disqualified.text")); // NOI18N
        fC1Disqualified.setName("fC1Disqualified"); // NOI18N

        fC2Injured.setText(resourceMap.getString("fC2Injured.text")); // NOI18N
        fC2Injured.setName("fC2Injured"); // NOI18N

        fC2Disqualified.setText(resourceMap.getString("fC2Disqualified.text")); // NOI18N
        fC2Disqualified.setName("fC2Disqualified"); // NOI18N

        fC1Won.setText(resourceMap.getString("fC1Won.text")); // NOI18N
        fC1Won.setName("fC1Won"); // NOI18N
        fC1Won.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                clickC1Won(evt);
            }
        });

        fC2Won.setText(resourceMap.getString("fC2Won.text")); // NOI18N
        fC2Won.setName("fC2Won"); // NOI18N
        fC2Won.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                clickC2Won(evt);
            }
        });

        javax.swing.GroupLayout mainPanelLayout = new javax.swing.GroupLayout(mainPanel);
        mainPanel.setLayout(mainPanelLayout);
        mainPanelLayout.setHorizontalGroup(
            mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(mainPanelLayout.createSequentialGroup()
                .addGap(25, 25, 25)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(fC1Name)
                    .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                        .addComponent(fC1Injured)
                        .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                            .addComponent(fC1Won)
                            .addComponent(fC1Disqualified))))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 103, Short.MAX_VALUE)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, mainPanelLayout.createSequentialGroup()
                        .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(fC2Injured)
                            .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                                .addComponent(fC2Won)
                                .addComponent(fC2Disqualified)))
                        .addGap(78, 78, 78))
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, mainPanelLayout.createSequentialGroup()
                        .addComponent(fC2Name)
                        .addGap(86, 86, 86))))
        );
        mainPanelLayout.setVerticalGroup(
            mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(mainPanelLayout.createSequentialGroup()
                .addGap(44, 44, 44)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(fC1Name, javax.swing.GroupLayout.PREFERRED_SIZE, 14, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(fC2Name))
                .addGap(18, 18, 18)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(fC1Injured)
                    .addComponent(fC2Injured))
                .addGap(18, 18, 18)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(fC1Disqualified)
                    .addComponent(fC2Disqualified))
                .addGap(31, 31, 31)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(fC2Won)
                    .addComponent(fC1Won))
                .addContainerGap(31, Short.MAX_VALUE))
        );

        setComponent(mainPanel);
    }// </editor-fold>//GEN-END:initComponents

private void clickC1Won(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_clickC1Won
    fMatch.getCompetitor1().setFlags(
        (fC1Injured.isSelected() ? Competitor.FLAG_INJURED : 0) |
        (fC1Disqualified.isSelected() ? Competitor.FLAG_DISQUALIFIED : 0)
    );
    fMatch.getCompetitor2().setFlags(
        (fC2Injured.isSelected() ? Competitor.FLAG_INJURED : 0) |
        (fC2Disqualified.isSelected() ? Competitor.FLAG_DISQUALIFIED : 0)
    );
    try {
        fDbConnection.setWinner(fMatch, 1);
        getNextMatch();
    }
    catch (Exception ex) {
        JOptionPane.showMessageDialog(null, "Error saving winner: " + ex, "Error", JOptionPane.ERROR_MESSAGE);
        ex.printStackTrace();
    }
}//GEN-LAST:event_clickC1Won

private void clickC2Won(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_clickC2Won
    fMatch.getCompetitor1().setFlags(
        (fC1Injured.isSelected() ? Competitor.FLAG_INJURED : 0) |
        (fC1Disqualified.isSelected() ? Competitor.FLAG_DISQUALIFIED : 0)
    );
    fMatch.getCompetitor2().setFlags(
        (fC2Injured.isSelected() ? Competitor.FLAG_INJURED : 0) |
        (fC2Disqualified.isSelected() ? Competitor.FLAG_DISQUALIFIED : 0)
    );
    try {
        fDbConnection.setWinner(fMatch, 1);
        getNextMatch();
    }
    catch (Exception ex) {
        JOptionPane.showMessageDialog(null, "Error saving winner: " + ex, "Error", JOptionPane.ERROR_MESSAGE);
        ex.printStackTrace();
    }
}//GEN-LAST:event_clickC2Won

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JCheckBox fC1Disqualified;
    private javax.swing.JCheckBox fC1Injured;
    private javax.swing.JLabel fC1Name;
    private javax.swing.JButton fC1Won;
    private javax.swing.JCheckBox fC2Disqualified;
    private javax.swing.JCheckBox fC2Injured;
    private javax.swing.JLabel fC2Name;
    private javax.swing.JButton fC2Won;
    private javax.swing.JPanel mainPanel;
    // End of variables declaration//GEN-END:variables
}
